==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        bg() {
            return new MoneyFlowIndexIndicator();
        }
        get_x6() {
            return 1;
        }
        get_yz() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return MoneyFlowIndexIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.zl));
        }
        set zk(a) {
            this.h(MoneyFlowIndexIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.zl = StrategyBasedIndicator.zh(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();

==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        bc() {
            return new MoneyFlowIndexIndicator();
        }
        get_x7() {
            return 1;
        }
        get_y0() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return MoneyFlowIndexIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.zm));
        }
        set zl(a) {
            this.h(MoneyFlowIndexIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.zm = StrategyBasedIndicator.zi(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();
